@@ -234,64 +234,6 @@ entry * parse_cron_entry(char *);
 				 * extern them elsewhere.
 				 */
 
-#ifdef MAIN_PROGRAM
-# if !defined(LINT) && !defined(lint)
-char	*copyright[] = {
-		"@(#) Copyright 1988,1989,1990,1993,1994 by Paul Vixie",
-		"@(#) All rights reserved"
-	};
-# endif
-
-char	*MonthNames[] = {
-		"Jan", "Feb", "Mar", "Apr", "May", "Jun",
-		"Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
-		NULL
-	};
-
-char	*DowNames[] = {
-		"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun",
-		NULL
-	};
-
-char	*ecodes[] = {
-		"no error",
-		"bad minute",
-		"bad hour",
-		"bad day-of-month",
-		"bad month",
-		"bad day-of-week",
-		"bad command",
-		"bad time specifier",
-		"bad username",
-		"command too long",
-		NULL
-	};
-
-
-char	*ProgramName;
-int	LineNumber;
-time_t	StartTime;
-time_min virtualTime;
-time_min clockTime;
-
-# if DEBUGGING
-int	DebugFlags;
-char	*DebugFlagNames[] = {	/* sync with #defines */
-		"ext", "sch", "proc", "pars", "load", "misc", "test", "bit",
-		NULL		/* NULL must be last element */
-	};
-# endif /* DEBUGGING */
-#else /*MAIN_PROGRAM*/
-extern	char	*copyright[],
-		*MonthNames[],
-		*DowNames[],
-		*ProgramName;
+extern	char *MonthNames[];
+extern	char *DowNames[];
 extern	int	LineNumber;
-extern	time_t	StartTime;
-extern  time_min virtualTime;
-extern  time_min clockTime;
-# if DEBUGGING
-extern	int	DebugFlags;
-extern	char	*DebugFlagNames[];
-# endif /* DEBUGGING */
-#endif /*MAIN_PROGRAM*/
