@@ -16,6 +16,7 @@
 #include "libpq-fe.h"
 #include "postmaster/bgworker.h"
 #include "storage/dsm.h"
+#include "storage/shm_mq.h"
 #include "utils/timestamp.h"
 
 
@@ -48,10 +49,13 @@ typedef struct CronTask
 	PGconn *connection;
 	PostgresPollingStatusType pollingStatus;
 	TimestampTz startDeadline;
+	TimestampTz lastStartTime;
+	uint32 secondsInterval;
 	bool isSocketReady;
 	bool isActive;
 	char *errorMessage;
 	bool freeErrorMessage;
+	shm_mq_handle *sharedMemoryQueue;
 	dsm_segment *seg;
 	BackgroundWorkerHandle handle;
 } CronTask;
