@@ -120,7 +120,7 @@ typedef enum
 /* forward declarations */
 void _PG_init(void);
 void _PG_fini(void);
-static void pg_cron_sigterm(SIGNAL_ARGS);
+static  void pg_cron_sigterm(SIGNAL_ARGS);
 static void pg_cron_sighup(SIGNAL_ARGS);
 PGDLLEXPORT void PgCronLauncherMain(Datum arg);
 PGDLLEXPORT void CronBackgroundWorker(Datum arg);
@@ -143,6 +143,7 @@ static void ManageCronTask(CronTask *task, TimestampTz currentTime);
 static void ExecuteSqlString(const char *sql);
 static void GetTaskFeedback(PGresult *result, CronTask *task);
 static void ProcessBgwTaskFeedback(CronTask *task, bool running);
+static void CronNoticeReceiver(void *arg, const PGresult *result);
 
 static bool jobCanceled(CronTask *task);
 static bool jobStartupTimeout(CronTask *task, TimestampTz currentTime);
@@ -167,7 +168,7 @@ static int MaxRunningTasks = 0;
 static int CronLogMinMessages = WARNING;
 static bool UseBackgroundWorkers = false;
 
-char  *cron_timezone = NULL;
+static char  *cron_timezone = NULL;
 
 static const struct config_enum_entry cron_message_level_options[] = {
 	{"debug5", DEBUG5, false},
@@ -1367,6 +1368,7 @@ ManageCronTask(CronTask *task, TimestampTz currentTime)
 
 				connection = PQconnectStartParams(keywordArray, valueArray, false);
 				PQsetnonblocking(connection, 1);
+				PQsetNoticeReceiver(connection, CronNoticeReceiver, (void *) task);
 
 				connectionStatus = PQstatus(connection);
 				if (connectionStatus == CONNECTION_BAD)
@@ -1619,8 +1621,8 @@ ManageCronTask(CronTask *task, TimestampTz currentTime)
 
 		case CRON_TASK_SENDING:
 		{
-			char *command = cronJob->command;
 			int sendResult = 0;
+			char *command = NULL;
 
 			Assert(!UseBackgroundWorkers);
 
@@ -1648,6 +1650,7 @@ ManageCronTask(CronTask *task, TimestampTz currentTime)
 				break;
 			}
 
+			command = cronJob->command;
 			sendResult = PQsendQuery(connection, command);
 			if (sendResult == 1)
 			{
@@ -1996,8 +1999,11 @@ ProcessBgwTaskFeedback(CronTask *task, bool running)
 							UpdateJobRunDetail(task->runId, NULL, GetCronStatus(CRON_STATUS_SUCCEEDED), display_msg.data, NULL, &end_time);
 					}
 
-					ereport(LOG, (errmsg("cron job " INT64_FORMAT ": %s",
-									 task->jobId, display_msg.data)));
+					/*
+					 * We do not log the message, since the original process probably
+					 * already did that.
+					 */
+
 					pfree(display_msg.data);
 
 					break;
@@ -2068,7 +2074,7 @@ CronBackgroundWorker(Datum main_arg)
 												 ALLOCSET_DEFAULT_MAXSIZE);
 
 	/* Set up a dynamic shared memory segment. */
-	seg = dsm_attach(DatumGetInt32(main_arg));
+	seg = dsm_attach(DatumGetUInt32(main_arg));
 	if (seg == NULL)
 		ereport(ERROR,
 				(errcode(ERRCODE_OBJECT_NOT_IN_PREREQUISITE_STATE),
@@ -2278,8 +2284,10 @@ ExecuteSqlString(const char *sql)
 			(void) PortalRun(portal, FETCH_ALL, isTopLevel, receiver, receiver, completionTag);
 		#elif PG_VERSION_NUM < 130000
 			(void) PortalRun(portal, FETCH_ALL, isTopLevel,true, receiver, receiver, completionTag);
-		#else
+		#elif PG_VERSION_NUM < 180000
 			(void) PortalRun(portal, FETCH_ALL, isTopLevel, true, receiver, receiver, &qc);
+		#else
+			(void) PortalRun(portal, FETCH_ALL, isTopLevel, receiver, receiver, &qc);
 		#endif
 
 		/* Clean up the receiver. */
@@ -2356,3 +2364,14 @@ jobStartupTimeout(CronTask *task, TimestampTz currentTime)
     else
         return false;
 }
+
+
+/*
+ * CronNoticeReceiver processes a libpq notice. We generally ignore
+ * these because they are usually already logged by the original process.
+ */
+static void
+CronNoticeReceiver(void *arg, const PGresult *result)
+{
+
+}
