@@ -30,6 +30,9 @@ static CronTask * GetCronTask(int64 jobId);
 static MemoryContext CronTaskContext = NULL;
 static HTAB *CronTaskHash = NULL;
 
+/* settings */
+bool LaunchActiveJobs = true;
+
 
 /*
  * InitializeTaskStateHash initializes the hash for storing task states.
@@ -100,8 +103,9 @@ RefreshTaskHash(void)
 	{
 		CronJob *job = (CronJob *) lfirst(jobCell);
 
-		CronTask *task = GetCronTask(job->jobId);
-		task->isActive = job->active;
+		task = GetCronTask(job->jobId);
+		task->isActive = LaunchActiveJobs && job->active;
+		task->secondsInterval = job->schedule.secondsInterval;
 	}
 
 	CronJobCacheValid = true;
@@ -122,6 +126,13 @@ GetCronTask(int64 jobId)
 	if (!isPresent)
 	{
 		InitializeCronTask(task, jobId);
+
+		/*
+		 * We only initialize last run when entering into the hash.
+		 * The net effect is that the timer for the first run of an
+		 * interval job starts when pg_cron first learns about the job.
+		 */
+		task->lastStartTime = GetCurrentTimestamp();
 	}
 
 	return task;
